@@ -127,12 +127,34 @@ class FileConstructor():
 		return True
 		
 
-	def from_diffgram_id():
 
+	def format_packet():
+		raise NotImplementedError
+
+
+	@staticmethod
+	def __media_packet_sanity_checks(packet) -> None:
+		"""
+		Relevant to new media, ie not existing media
+		"""
+
+		if type(packet) != dict:
+			raise Exception("packet is not a dict")
+
+		if "media" not in packet:
+			raise Exception(" 'media' key is not defined in packet.")  
+
+		if "url" not in packet["media"]:
+			raise Exception(" 'url' key is not defined in packet['media'] .")
+
+		media_type = packet["media"].get("type", None)
+		if not media_type:
+			raise Exception(" 'type' key is not defined in packet['media'] use one of ['image', 'video']")
+
+
+	def __validate_existing_instances():
 		pass
 
-	
-
 	def from_packet(
 			self, 
 			packet,
@@ -184,72 +206,33 @@ class FileConstructor():
 		and makes request to /input/packet endpoint.
 
 		"""
-
-		if type(packet) != dict:
-			raise Exception("packet is not a dict")
-
-		if "media" not in packet:
-			raise Exception(" 'media' key is not defined in packet.")  
-
-		if "url" not in packet["media"]:
-			raise Exception(" 'url' key is not defined in packet['media'] .")
-
-		# TODO determine if local path or url, for now assume it's a URL?
-
-		media_type = packet["media"].get("type", None)
-		if not media_type:
-			raise Exception(" 'type' key is not defined in packet['media'] use one of ['image', 'video']")
-		# QUESTION should we default this to "image"
+		file_id = packet.get('file_id')
+		if not file_id:
+			FileConstructor.__media_packet_sanity_checks(packet = packet)
 
 		instance = None
-
-		if media_type == "image":
-			
-			if packet.get("instance_list"):	
+	
+		if packet.get("instance_list"):					
+			packet['instance_list'] = self.__validate_and_format_instance_list(
+				instance_list = packet.get('instance_list'),
+				assume_new_instances_machine_made = assume_new_instances_machine_made,
+				convert_names_to_label_files = convert_names_to_label_files
+				)
 				
-				instance_list = packet.get('instance_list')
-				
-				self.check_instance_list(instance_list)
-
-				self.format_assumptions(
-					instance_list = instance_list,
-					assume_new_instances_machine_made = assume_new_instances_machine_made)
-
-				if convert_names_to_label_files is True:
-					packet["instance_list"] = self.instance_list_label_strings_to_ids(
-						instance_list = instance_list
-						)
-
-
-		if media_type == "video":
-			if packet.get("frame_packet_map"):
-
-				if type(packet["frame_packet_map"]) != dict:
-					raise Exception("frame_packet_map is not a dict")
-
-				for frame, instance_list in packet["frame_packet_map"].items():
-					
-					if type(frame) != int:
-						raise Exception("frame is not a integer. The key should be the integer frame number.")
-
-					if type(instance_list) != list:
-						raise Exception("instance_list is not a list. The value of the frame shuold be a list of instance dicts.")
-
-					self.check_instance_list(instance_list)
-
-					self.format_assumptions(
-						instance_list = instance_list,
-						assume_new_instances_machine_made = assume_new_instances_machine_made)
-
-					if convert_names_to_label_files is True:
-						packet["instance_list"] = self.instance_list_label_strings_to_ids(
-							instance_list = instance_list
-							)
+		if packet.get("frame_packet_map"):
+			packet['frame_packet_map'] = self.__validate_and_format_frame_packet_map(
+				frame_packet_map = packet['frame_packet_map'],
+				assume_new_instances_machine_made = assume_new_instances_machine_made,
+				convert_names_to_label_files = convert_names_to_label_files
+				)
 
 		# Test one of the instances
 		# QUESTION Should we be testing all? User option maybe?
 		# (Otherwise invalid ones get discarded when it hits API)
 
+		# TODO due to changes, this no longer tests anything , choose new way to sample
+		# instance list / packets here.
+
 		if instance:
 			instance_type = instance.get("type", None)
 			if not instance_type:
@@ -269,6 +252,7 @@ class FileConstructor():
 			packet["mode"] = "attach_to_job"
 
 
+
 		endpoint = "/api/walrus/v1/project/" + \
 			self.client.project_string_id + "/input/packet"
 
@@ -292,6 +276,56 @@ class FileConstructor():
 			#return file
 
 
+	def __validate_and_format_frame_packet_map(
+			self, 
+			frame_packet_map: dict,
+			assume_new_instances_machine_made: bool = True,
+			convert_names_to_label_files: bool = True):
+		"""
+		Warning: Mutates packet map
+		"""
+
+		if type(frame_packet_map) != dict:
+			raise Exception("frame_packet_map is not a dict")
+
+		for frame, instance_list in frame_packet_map.items():
+					
+			if type(frame) != int:
+				raise Exception("frame is not a integer. The key should be the integer frame number.")
+
+			if type(instance_list) != list:
+				raise Exception("instance_list is not a list. The value of the frame should be a list of instance dicts.")
+
+			frame_packet_map[frame] = self.__validate_and_format_instance_list(
+				instance_list = instance_list,
+				assume_new_instances_machine_made = assume_new_instances_machine_made,
+				convert_names_to_label_files = convert_names_to_label_files
+				)
+
+		return frame_packet_map
+
+
+	def __validate_and_format_instance_list(
+			self,
+			instance_list: list,
+			assume_new_instances_machine_made: bool,
+			convert_names_to_label_files: bool):
+
+
+		FileConstructor.sanity_check_instance_list(instance_list)
+
+		instance_list = FileConstructor.format_assumptions(
+			instance_list = instance_list,
+			assume_new_instances_machine_made = assume_new_instances_machine_made)
+
+		if convert_names_to_label_files is True:
+			instance_list = self.instance_list_label_strings_to_ids(
+				instance_list = instance_list
+				)
+
+		return instance_list
+
+
 	def instance_list_label_strings_to_ids(self, instance_list: list):
 
 		# Convert "name" label (ie == "cat") to Project label_file id
@@ -303,7 +337,8 @@ class FileConstructor():
 		return instance_list
 
 
-	def check_instance_list(self, instance_list: list):
+	@staticmethod
+	def sanity_check_instance_list(instance_list: list):
 
 		if type(instance_list) != list:
 			raise Exception("instance_list is not array like")
@@ -314,8 +349,8 @@ class FileConstructor():
 		return
 
 
+	@staticmethod
 	def format_assumptions(
-			self,
 			instance_list: list,
 			assume_new_instances_machine_made: bool):
 
@@ -338,3 +373,31 @@ class FileConstructor():
 		"""
 		pass
 
+
+	def get_by_id(self, 
+				  id: int):
+		"""
+		returns Diffgram File object
+		"""
+	
+		endpoint = "/api/v1/file/view"
+
+		spec_dict = {
+			'file_id': id,
+			'project_string_id': self.client.project_string_id
+			}
+
+		response = self.client.session.post(
+			self.client.host + endpoint,
+			json = spec_dict)
+		
+		self.client.handle_errors(response)
+
+		response_json = response.json()
+
+		return File.new(
+			client = self.client,
+			file_json = response_json.get('file'))
+
+
+
